.. _contents:

NetworkX documentation
======================

.. only:: html

    :Release: |version|
    :Date: |today|

    Download `PDF <http://networkx.lanl.gov/networkx.pdf>`_
    `HTML <http://networkx.lanl.gov/networkx-documentation.zip>`_


.. toctree::
   :maxdepth: 2

   install
   tutorial/index
   reference/index
   reference/history
   reference/credits      
   reference/legal
   reference/citing
   download

.. only:: html

   - `Examples <examples/index.html>`_

.. only:: html

   - `Gallery <gallery/index.html>`_




   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
* :ref:`glossary`

